@@ -12,8 +12,7 @@ MainWidget::MainWidget(QWidget *parent) :
     QWidget(parent),
     m_mediaObject_tor(new Phonon::MediaObject(this)),
     m_mediaObject_pfeife(new Phonon::MediaObject(this)),
-    m_audioOutput_tor(new Phonon::AudioOutput(Phonon::MusicCategory, this)),
-    m_audioOutput_pfeife(new Phonon::AudioOutput(Phonon::MusicCategory, this)),
+    m_audioOutput(new Phonon::AudioOutput(Phonon::MusicCategory, this)),
     m_backend(new BackendKicker(this)),
     m_datamodel(new MatchDayModel(this, m_backend)),
     m_scoretbl(new ScoreTable(m_datamodel)),
@@ -61,15 +60,23 @@ MainWidget::MainWidget(QWidget *parent) :
     m_mediaObject_tor->setCurrentSource(Phonon::MediaSource("/usr/share/buliscores/tor.wav"));
     m_mediaObject_pfeife->setCurrentSource(Phonon::MediaSource("/usr/share/buliscores/trillerpfeife.wav"));
 
-    Phonon::createPath(m_mediaObject_tor,     m_audioOutput_tor);
-    Phonon::createPath(m_mediaObject_pfeife,  m_audioOutput_pfeife);
+    Phonon::createPath(m_mediaObject_tor,     m_audioOutput);
+    Phonon::createPath(m_mediaObject_pfeife,  m_audioOutput);
 }
 
-// only needed for testing on desktop
 void MainWidget::mousePressEvent(QMouseEvent* event)
 {
+    qDebug() << "widget tapped";
+
+    // only needed for testing on desktop
     if (event->button() == Qt::RightButton) {
         this->showSettingsDialog();
+    } else {
+//        qDebug() << "current volume: " << m_audioOutput->volumeDecibel();
+//        qDebug() << "MO state: " << m_mediaObject_pfeife->state();
+//        m_mediaObject_pfeife->seek(0);
+//        m_mediaObject_pfeife->play();
+//        qDebug() << "MO state 2: " << m_mediaObject_pfeife->state();
     }
 }
 
@@ -106,6 +113,7 @@ void MainWidget::onMatchAdded(Match* match) {
 void MainWidget::onScoreChange()
 {
     if (m_settings.value("Sounds", false).toBool()) {
+        m_mediaObject_tor->seek(0);
         m_mediaObject_tor->play();
         qDebug() << "Playing sound: tor";
     }
@@ -114,6 +122,7 @@ void MainWidget::onScoreChange()
 void MainWidget::onMatchStateChanged(Match::MatchState)
 {
     if (m_settings.value("Sounds", false).toBool()) {
+        m_mediaObject_pfeife->seek(0);
         m_mediaObject_pfeife->play();
         qDebug() << "Playing sound: trillerpfeife";
     }
