@@ -35,8 +35,7 @@ protected slots:
 private:
     Phonon::MediaObject *m_mediaObject_tor;
     Phonon::MediaObject *m_mediaObject_pfeife;
-    Phonon::AudioOutput *m_audioOutput_tor;
-    Phonon::AudioOutput *m_audioOutput_pfeife;
+    Phonon::AudioOutput *m_audioOutput;
 
     MatchDayBackend* m_backend;
     MatchDayModel*   m_datamodel;
@@ -48,7 +47,7 @@ private:
     QLabel      m_statuslbl;
 
 private slots:
-    void update(void);
+    void onSettingsAccepted(void);
 
 };
 
